@@ -19,6 +19,7 @@ from .os import has_command, reset_fds
 
 REQ_TIMEOUT = 1
 INSTALL_TIMEOUT = 30
+V0 = VersionInfo.parse("0.0.0")
 
 
 class SymUpdater:
@@ -39,7 +40,10 @@ class SymUpdater:
         return not self.is_local() and Config.check_for_update()
 
     def get_current_version(self) -> VersionInfo:
-        return VersionInfo.parse(self.module.version.__version__)
+        try:
+            return VersionInfo.parse(self.module.version.__version__)
+        except ValueError:
+            return V0
 
     def get_latest_version(self) -> Optional[VersionInfo]:
         try:
@@ -97,8 +101,17 @@ class SymUpdater:
             return version > self.get_current_version()
         return False
 
+    def _env_is_local(self):
+        return (
+            os.getenv("SENTRY_ENVIRONMENT") == "development" or os.getenv("CI") == "true"
+        )
+
     def is_local(self):
-        return (self.dir / ".git").exists() or self.get_current_version() == "0.0.0"
+        return (
+            (self.dir / ".git").exists()
+            or self.get_current_version() == V0
+            or self._env_is_local()
+        )
 
     def is_pipx(self):
         return (Path.home() / ".local" / "pipx") in self.dir.parents
