@@ -62,6 +62,22 @@ class TestWriteCreds:
             written_creds = self.get_credentials_from_file(credentials_path, TEST_PROFILE)
             expect(written_creds).to(have_keys(creds_env))
 
+    def test_execute_write_creds_session_length(self, setup, credentials_path, creds_env):
+        with setup():
+            global_options = GlobalOptions(saml_client_type=AwsOkta, session_length=60)
+
+            request_data = RequestData(
+                action="write_creds",
+                resource=TEST_RESOURCE,
+                global_options=global_options,
+                params={"path": str(credentials_path), "profile": TEST_PROFILE},
+            )
+            action = WriteCredsAction()
+            action.execute(request_data)
+
+            written_creds = self.get_credentials_from_file(credentials_path, TEST_PROFILE)
+            expect(written_creds).to(have_keys(creds_env))
+
     @patch("sym.cli.saml_clients.saml_client.SAMLClient.write_creds")
     def test_execute_write_creds_prefix(self, mock_write_creds, setup, credentials_path):
         with setup():
@@ -265,7 +281,7 @@ class TestWriteCreds:
         like the creds_env fixture easily.
         """
 
-        config = ConfigParser()
+        config = ConfigParser(strict=False)
         with open(path) as f:
             config.read_file(f)
 
